#!/usr/bin/python
# Authors:
#     Endi S. Dewata <edewata@redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Copyright (C) 2015 Red Hat, Inc.
# All rights reserved.
#

import base64
import getopt
import ldap
import os
import sys

import pki.cli
from pki.server import PKISubsystem


class ConfigCLI(pki.cli.CLI):

    def __init__(self):
        super(ConfigCLI, self).__init__('config',
                                        'Configuration management commands')

        self.add_module(ConfigShowCLI())

    @staticmethod
    def print_config(config, all=False):

        print '  Instance ID: %s' % config['service.instanceID']
        print '  Instance Directory: %s' % config['service.instanceDir']
        print '  Port: %s' % config['service.unsecurePort']
        print '  Secure Port: %s' % config['service.securePort']
        print '  Client Auth Secure Port: %s' % config['service.clientauth_securePort']
        print '  Non-Client Auth Secure Port: %s' % config['service.non_clientauth_securePort']
        print '  Security Domain Port: %s' % config['service.securityDomainPort']


class ConfigShowCLI(pki.cli.CLI):

    def __init__(self):
        super(ConfigShowCLI, self).__init__('show', 'Show configuration')

    def print_help(self):
        print 'Usage: pki-server %s [OPTIONS]' % self.get_full_name()
        print
        print '  -s, --subsystem <directory>  Subsystem directory (default: /var/lib/pki-ca).'
        print
        print '  -v, --verbose                Run in verbose mode.'
        print '      --help                   Show help message.'
        print

    def execute(self, argv):

        try:
            opts, args = getopt.gnu_getopt(argv, 's:v', [
                'subsystem=',
                'verbose', 'help'])

        except getopt.GetoptError as e:
            print 'ERROR: ' + str(e)
            self.print_help()
            sys.exit(1)

        subsystem_dir = '/var/lib/pki-ca'

        for o, a in opts:
            if o in ('-v', '--verbose'):
                self.set_verbose(True)

            elif o == '--help':
                self.print_help()
                sys.exit()

            elif o in ('-s', '--subsystem'):
                subsystem_dir = a

            else:
                print 'ERROR: unknown option ' + o
                self.print_help()
                sys.exit(1)

        subsystem = PKISubsystem(subsystem_dir)

        ConfigCLI.print_config(subsystem.config)
